import { join } from 'path';
import { readdirSync, readFileSync } from 'fs';
import * as XLSX from 'xlsx';

export class DataExtractor {
    private static instance: DataExtractor;
    private data: { [key: string]: any } = {};

    private constructor() {
        this.loadAllData();
    }

    public static getInstance(): DataExtractor {
        if (!DataExtractor.instance) {
            DataExtractor.instance = new DataExtractor();
        }
        return DataExtractor.instance;
    }

    private loadAllData(): void {
        const dirPath = join(__dirname, '../../data');
        const files = readdirSync(dirPath).filter(file => file.endsWith('.xlsx'));
        console.log("Path is " + files);

        files.forEach(file => {
            const filePath = join(dirPath, file);
            this.data[file] = this.parseExcel(filePath);
        });
    }

    private parseExcel(filePath: string): any {
        const file = readFileSync(filePath);
        const workbook = XLSX.read(file, { type: 'buffer' });
        const sheetNames = workbook.SheetNames;
        const data = sheetNames.map(sheetName => ({
            sheetName,
            data: XLSX.utils.sheet_to_json(workbook.Sheets[sheetName])
        }));
        return data;
    }

    public getData(fileName: string): any {
        return this.data[fileName];
    }

    public getAvailableFiles(): string[] {
        return Object.keys(this.data);
    }
}
